package cn.estsh.i3plus.core.apiservice.websocket;

import cn.estsh.i3plus.core.api.iservice.busi.ISysMessageService;
import cn.estsh.i3plus.pojo.base.enumutil.ImppEnumUtil;
import com.alibaba.fastjson.JSON;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import javax.websocket.*;
import javax.websocket.server.PathParam;
import javax.websocket.server.ServerEndpoint;
import java.io.IOException;
import java.util.List;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.ConcurrentMap;

/**
 * @Description : 消息
 * @Reference :
 * @Author : yunhao
 * @CreateDate : 2018-11-24 16:57
 * @Modify:
 **/
@ServerEndpoint(value="/message-websocket/{userId}")
@Component
public class MessageWebSocket {

    private static final Logger LOGGER = LoggerFactory.getLogger(MessageWebSocket.class);

    private Long userId = 1L;

    //在线连接数
    private static int onlineCount = 0;

    //concurrent线程安全集合，存放客户端websocket对象
    private static ConcurrentMap<Long,MessageWebSocket> webSocketSet = new ConcurrentHashMap<Long,MessageWebSocket>();

    //websocket会话
    private Session session;

    public static ConcurrentMap<Long, MessageWebSocket> getWebSocketSet() {
        return webSocketSet;
    }

    @Autowired
    private ISysMessageService sysMessageService;


    @OnOpen
    public void onOpen(@PathParam("userId")Long userId, Session session){
        this.session = session;
        this.userId = userId;

        webSocketSet.put(userId,this);     //加入set中
        addOnlineCount();           //在线数加1
        LOGGER.info("{}加入！当前在线人数为{}",userId,getOnlineCount());
    }

    /**
     * 连接关闭调用的方法
     */
    @OnClose
    public void onClose() {
        webSocketSet.remove(this.userId);  //从set中删除
        subOnlineCount();           //在线数减1
        LOGGER.info("有一连接关闭！当前在线人数为" + getOnlineCount());
    }

    /**
     * 收到客户端消息后调用的方法
     *
     * @param message 客户端发送过来的消息*/
    @OnMessage
    public void onMessage(String message, Session session) {
        LOGGER.info("来自客户端的消息:" + message);
    }

    /**
     * 发生错误时调用
     * @OnError
     */
    @OnError
    public void onError(Session session, Throwable error) {
        LOGGER.info("发生错误");
        error.printStackTrace();
    }

    public void sendMessage() throws IOException {
        List userMessageList = sysMessageService.findSysRefUserMessageByUserIdAndStatus(this.userId,
                ImppEnumUtil.MESSAGE_STATUS.UNREAD.getValue());
        this.session.getBasicRemote().sendText(JSON.toJSONString(userMessageList));
    }

    public static synchronized int getOnlineCount() {
        return onlineCount;
    }

    public static synchronized void addOnlineCount() {
        MessageWebSocket.onlineCount++;
    }

    public static synchronized void subOnlineCount() {
        MessageWebSocket.onlineCount--;
    }
}
